version 13.0
log using "/Users/mrg19/Dropbox/kostanca_religion/replication/data_analysis/aggregate/aggregate.log", replace
#delimit ;

*     *********************************************************************** 	*;
*     *********************************************************************** 	*;
*       File-Name:    	aggregate.do				                            *;
*       Date:           May 29, 2019	                                   	    *;
*       Author:         MRG/KD                                                  *;
*       Purpose:       	Run the analysis for aggregate religious participation  *;
*                       and aggregate religious belief.				 			*;
* 	    Input File:     aggregate_religious_participation.dta and			 	*;
*						final_aggregate.dta	   				 					*;
*       Output File:    aggregate.log											*;
*       Data Output:    none			                        				*;             
*       Previous file:    														*;
*       Machine:        desktop/laptop         									*;
*     *********************************************************************** 	*;
*     *********************************************************************** 	*;

set more off;

*     *********************************************************************** 	*;
*       Replicate GGS -- Models 1, 2, and 3 in Table 1                          *;
*     *********************************************************************** 	*;

use "/Users/mrg19/Dropbox/kostanca_religion/replication/data_analysis/aggregate/aggregate_religious_participation.dta", clear;

*  Model 1 *;
regress attend_religious_services lhdi government_regulation social_regulation   
        sub_saharan south_asia east_asia se_asia oceania middle_east latin_america north_america east_europe west_europe 
        wave2 wave3 wave4, cluster(ccode);

*  Model 2 *;   
regress attend_religious_services lhdi government_regulation social_regulation  
        inequality_gini communist postcommunist roman_catholic_alesina protestant_alesina muslim_alesina 
        sub_saharan south_asia east_asia se_asia oceania middle_east latin_america north_america east_europe west_europe 
        wave2 wave3 wave4, cluster(ccode);

*  Model 3 *;    
regress attend_religious_services lgdp1000 government_regulation social_regulation  
        inequality_gini communist postcommunist roman_catholic_alesina protestant_alesina muslim_alesina 
        sub_saharan south_asia east_asia se_asia oceania middle_east latin_america north_america east_europe west_europe 
        wave2 wave3 wave4, cluster(ccode);

clear;

*     *********************************************************************** 	*;
*		Open our dataset and prepare for replication -- Models 4-9				*;
*     *********************************************************************** 	*;

use "/Users/mrg19/Dropbox/kostanca_religion/replication/data_analysis/aggregate/final_aggregate.dta", clear;

desc;

sum;

*     *********************************************************************** 	*;
*		Create log of modernization variables									*;
*     *********************************************************************** 	*;

gen lhdi2 = ln(hdi2);
label var lhdi "natural log of hdi (UNDP HDR Office)";

gen lgdppc = ln(gdppc);
label var lgdppc "natural log of gdppc";

mi set wide;

mi xtset ccode ;

*     *********************************************************************** 	*;
*		Replication results in Models 4-9 in Table 1.   						*;
*		mibeta gives standardized coefficients and r-squareds				    *;
*     *********************************************************************** 	*;

*  Model 4 *;
mi estimate: reg religion_attend lhdi2 government_regulation social_regulation i.subregion_un i.wave, cluster(ccode);

mibeta religion_attend lhdi2 government_regulation social_regulation i.subregion_un i.wave, cluster(ccode);

*  Model 5 *;
mi estimate: reg religion_attend lhdi2 government_regulation social_regulation gini_disp 
		communist postcommunist catholic_alesina protestant_alesina muslim_alesina i.subregion_un i.wave, cluster(ccode);
		
mibeta religion_attend lhdi2 government_regulation social_regulation gini_disp 
		communist postcommunist catholic_alesina protestant_alesina muslim_alesina i.subregion_un i.wave, cluster(ccode);

*  Model 6 *;
mi estimate: reg religion_attend lgdppc government_regulation social_regulation gini_disp 
		communist postcommunist catholic_alesina protestant_alesina muslim_alesina i.subregion_un i.wave, cluster(ccode)
		;
mibeta religion_attend lgdppc government_regulation social_regulation gini_disp 
		communist postcommunist catholic_alesina protestant_alesina muslim_alesina i.subregion_un i.wave, cluster(ccode);

*  Model 7 *;
mi estimate: reg believe_god lhdi2 government_regulation social_regulation i.subregion_un i.wave, cluster(ccode);

mibeta believe_god lhdi2 government_regulation social_regulation i.subregion_un i.wave, cluster(ccode);

*  Model 8 *;
mi estimate: reg believe_god lhdi2 government_regulation social_regulation gini_disp 
		communist postcommunist catholic_alesina protestant_alesina muslim_alesina i.subregion_un i.wave, cluster(ccode);

mibeta believe_god lhdi2 government_regulation social_regulation gini_disp 
		communist postcommunist catholic_alesina protestant_alesina muslim_alesina i.subregion_un i.wave, cluster(ccode);

*  Model 9 *;
mi estimate: reg believe_god lgdppc government_regulation social_regulation gini_disp 
		communist postcommunist catholic_alesina protestant_alesina muslim_alesina i.subregion_un i.wave, cluster(ccode);

mibeta believe_god lgdppc government_regulation social_regulation gini_disp 
		communist postcommunist catholic_alesina protestant_alesina muslim_alesina i.subregion_un i.wave, cluster(ccode);

*     *********************************************************************** 	*;
*		Replicate results for Table 2.											*;
*     *********************************************************************** 	*;

*  Model 1 *;
mi estimate: reg religion_attend life_expectancy government_regulation social_regulation gini_disp 
		communist postcommunist catholic_alesina protestant_alesina muslim_alesina i.subregion_un i.wave, cluster(ccode);
		
mibeta religion_attend life_expectancy government_regulation social_regulation gini_disp 
		communist postcommunist catholic_alesina protestant_alesina muslim_alesina i.subregion_un i.wave, cluster(ccode);

*  Model 2 *;
mi estimate: reg religion_attend education government_regulation social_regulation gini_disp 
		communist postcommunist catholic_alesina protestant_alesina muslim_alesina i.subregion_un i.wave, cluster(ccode);

mibeta religion_attend education government_regulation social_regulation gini_disp 
		communist postcommunist catholic_alesina protestant_alesina muslim_alesina i.subregion_un i.wave, cluster(ccode);

*  Model 3*;
mi estimate: reg religion_attend gni government_regulation social_regulation gini_disp 
		communist postcommunist catholic_alesina protestant_alesina muslim_alesina i.subregion_un i.wave, cluster(ccode);
		
mibeta religion_attend gni government_regulation social_regulation gini_disp 
		communist postcommunist catholic_alesina protestant_alesina muslim_alesina i.subregion_un i.wave, cluster(ccode);

*  Model 4 *;
mi estimate: reg believe_god life_expectancy government_regulation social_regulation gini_disp 
		communist postcommunist catholic_alesina protestant_alesina muslim_alesina i.subregion_un i.wave, cluster(ccode);
		
mibeta believe_god life_expectancy government_regulation social_regulation gini_disp 
		communist postcommunist catholic_alesina protestant_alesina muslim_alesina i.subregion_un i.wave, cluster(ccode);

*  Model 5 *;
mi estimate: reg believe_god education government_regulation social_regulation gini_disp 
		communist postcommunist catholic_alesina protestant_alesina muslim_alesina i.subregion_un i.wave, cluster(ccode);

mibeta believe_god education government_regulation social_regulation gini_disp 
		communist postcommunist catholic_alesina protestant_alesina muslim_alesina i.subregion_un i.wave, cluster(ccode);

*  Model 6*;
mi estimate: reg believe_god gni government_regulation social_regulation gini_disp 
		communist postcommunist catholic_alesina protestant_alesina muslim_alesina i.subregion_un i.wave, cluster(ccode);
		
mibeta believe_god gni government_regulation social_regulation gini_disp 
		communist postcommunist catholic_alesina protestant_alesina muslim_alesina i.subregion_un i.wave, cluster(ccode);

*     *********************************************************************** 	*;
*		Replication complete													*;
*     *********************************************************************** 	*;

log close;

clear;



